@@ -1,5 +1,7 @@
 readAsciiGrid <- function(fname, as.image = FALSE, plot.image = FALSE,
-	colname=basename(fname), proj4string = CRS(as.character(NA))) {
+	colname=basename(fname), proj4string = CRS(as.character(NA)), 
+	dec=options()$OutDec) {
+	if (dec == ".") pdec = "\\."
 	t = file(fname, "r")
 	l5 = readLines(t, n = 6)
 	# instead of:
@@ -10,21 +12,21 @@ readAsciiGrid <- function(fname, as.image = FALSE, plot.image = FALSE,
 	for (i in 1:6) {
 		fieldname = casefold(l5s[[i]][1])
 		if (length(grep("ncols", fieldname)))
-			ncols = as.numeric(l5s[[i]][2])
+			ncols = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("nrows", fieldname)))
-			nrows = as.numeric(l5s[[i]][2])
+			nrows = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("xllcorner", fieldname)))
-			xllcorner = as.numeric(l5s[[i]][2])
+			xllcorner = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("yllcorner", fieldname)))
-			yllcorner = as.numeric(l5s[[i]][2])
+			yllcorner = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("xllcenter", fieldname)))
-			xllcenter = as.numeric(l5s[[i]][2])
+			xllcenter = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("yllcenter", fieldname)))
-			yllcenter = as.numeric(l5s[[i]][2])
+			yllcenter = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("cellsize", fieldname)))
-			cellsize = as.numeric(l5s[[i]][2])
+			cellsize = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 		if (length(grep("nodata_value", fieldname)))
-			nodata.value = as.numeric(l5s[[i]][2])
+			nodata.value = as.numeric(sub(pdec, ".", l5s[[i]][2]))
 	}
 	if (is.na(xllcorner) && !is.na(xllcenter))
 		xllcorner = xllcenter - 0.5 * cellsize
@@ -34,7 +36,7 @@ readAsciiGrid <- function(fname, as.image = FALSE, plot.image = FALSE,
 		yllcorner = yllcenter - 0.5 * cellsize
 	else
 		yllcenter = yllcorner + 0.5 * cellsize
-	map = scan(t, as.numeric(0), quiet = TRUE)
+	map = scan(t, as.numeric(0), quiet = TRUE, dec=dec)
 	close(t)
 	if (length(as.vector(map)) != nrows * ncols)
 		stop("dimensions of map do not match that of header")
@@ -55,7 +57,8 @@ readAsciiGrid <- function(fname, as.image = FALSE, plot.image = FALSE,
 	SpatialGridDataFrame(grid, data = df, proj4string=proj4string)
 }
 
-writeAsciiGrid <- function(x, fname, attr = 1, na.value = -9999, ...) { 
+writeAsciiGrid <- function(x, fname, attr = 1, na.value = -9999, 
+	dec=options()$OutDec, ...) { 
 
 # R> gridparameters(meuse.grid)
 #   cellcentre.offset cellsize cells.dim
@@ -68,7 +71,7 @@ writeAsciiGrid <- function(x, fname, attr = 1, na.value = -9999, ...) {
 #YLLCORNER 329400.000000
 #CELLSIZE 40.000000
 #NODATA_VALUE 1e31
-
+#	if (dec == ".") dec = "\\."
 	if (!gridded(x))
 		stop("can only write SpatialGridDataFrame objects to asciigrid")
 	x = as(x, "SpatialGridDataFrame")
@@ -81,17 +84,17 @@ writeAsciiGrid <- function(x, fname, attr = 1, na.value = -9999, ...) {
 	else
 		stop("Asciigrid does not support grids with non-square cells")
 	f = file(fname, open = "w")
-	writeLines(c(
-		paste("NCOLS", gp$cells.dim[1]),
-		paste("NROWS", gp$cells.dim[2]),
-		paste("XLLCORNER", gp$cellcentre.offset[1] - 0.5 * gp$cellsize[1]),
-		paste("YLLCORNER", gp$cellcentre.offset[2] - 0.5 * gp$cellsize[2]),
-		paste("CELLSIZE", gp$cellsize[1]),
-		paste("NODATA_VALUE", na.value)
-	  ), f)
+    	writeLines(c(paste("NCOLS", format(gp$cells.dim[1], decimal.mark=dec)), 
+        paste("NROWS", format(gp$cells.dim[2], decimal.mark=dec)), 
+        paste("XLLCORNER", format(gp$cellcentre.offset[1] - 
+		0.5 * gp$cellsize[1], decimal.mark=dec)), 
+        paste("YLLCORNER", format(gp$cellcentre.offset[2] - 
+        	0.5 * gp$cellsize[2], decimal.mark=dec)), 
+        paste("CELLSIZE", format(gp$cellsize[1], decimal.mark=dec)), 
+        paste("NODATA_VALUE", format(na.value, decimal.mark=dec))), f)
 	z = x@data[[attr]]
 	z[is.na(z)] = na.value
 	write.table(t(matrix(z, gp$cells.dim[1], gp$cells.dim[2])), file = f, 
-			row.names = FALSE, col.names = FALSE, ...)
+			row.names = FALSE, col.names = FALSE, dec=dec, ...)
 	close(f)
 }
